#Downloading R; installing packages
#Go to www.r-project.org, click on "CRAN" under "Download" in the list on the left side, choose a mirror, then look
#at the "Download and Install R" section.
#Packages, which extend the capabilities of R, may also be downloaded from the CRAN mirrors. Alternatively, one
#may use the install.packages command, as in this example:

install.packages("mixtools")
library(mixtools)
example(npEMindrep)

#new to R? 
#########################

help.start()

#check your working directory and what is in the directory
getwd()
dir() 

#basic arithmetics in R
#########################

a <- c(1,2);b <- c(1,3)
a==b
identical(a,b)
a <- c(TRUE,TRUE,FALSE,FALSE);b <- c(TRUE,FALSE,TRUE,FALSE)
!a
?"!"
a & b
a | b
xor(a,b)

#some important object types
#########################

# dataframe

character <- c("shrek","donkey","aladdin","simba","luke")
gender <- c("ogre","donkey","human","lion","jedi")
power <- c(4,2,1,3,5)
size <- c(245,150,180,100,190)
number <- c(26,35,13,46,8)
random <- sample(50:100,5)
frame <- data.frame(character,gender,power,size,number,random)

frame[order(frame$power),]
frame$character[frame$random>75]
frame$gender[frame$character=="simba"]
frame$character[frame$number>30 & frame$size<140]
frame$character[frame$number<30 | frame$size<120]

# vector

c(-2,-1,0,1,2)
seq(-2,2)
x <- -2:2
c(x + 2,5)
y <- rep(5,5)
z <- c(rep(-1,2),rep(1,3))
c(x,y,z)
x[x >= 0]

# function

taste <- function(c) {
  if (c == "spinach") {
    "yerk"
  }
  else if (c == "chips") {
    "miam"
  }
  else {
    "nothing to do"
  }
}

example.object1 <- "tomato"
example.object2 <- c("spinach","tomato") 
taste(example.object1)
taste(example.object2)

#getting some data and basic operations on them
#########################

hip <- read.table("http://astrostatistics.psu.edu/datasets/HIP_star.dat",
     header=T,fill=T) # T is short for TRUE
#hip <- read.table("HIP_star.dat", header=T,fill=T)

dim(hip)
names(hip)
hip[1,]
hip[1:20,7]
sum(hip[,3])

for(i in 1:ncol(hip)) {
  print(c(max(hip[,i]), min(hip[,i]), median(hip[,i]), mad(hip[,i])))
}
apply(hip, 2, max)
apply(hip, 2, min)
apply(hip, 2, median)

sum(is.na(hip[,9]))
which(is.na(hip[,9]))

for(i in 1:ncol(hip)) {
  print(c(max(hip[,i],na.rm=T), min(hip[,i],na.rm=T), median(hip[,i],na.rm=T), mad(hip[,i],na.rm=T)))
}

sort(hip[1:10,3])
hip[order(hip[1:10,3]),]

which.min(hip[,4])
tmp <- (hip[,4]==min(hip[,4]))
(1:nrow(hip))[tmp] # or equivalently,
which(tmp)

#visualizing data
attach(hip)
boxplot(Vmag~cut(B.V,breaks=(-1:6)/2),
        notch=T, varwidth=T, las=1, tcl=.5,
        xlab=expression(B - V),
        ylab=expression(V[mag]),
        main="Can you find the red giants?",
        cex=1, cex.lab=1.4, cex.axis=.8, cex.main=1)
axis(2, labels=F, at=0:12, tcl=-.25)
axis(4, at=3*(0:4))

example(plotmath)

#doing some testing with data: you have heard about a regression model and t-test
help.search("regression")
help.search("ttest")
help.search("t.test")

source("http://www.stat.psu.edu/~dhunter/R/confidence.band.r")
tmpx <- 1:10
tmpy <- 1:10+rnorm(10) # Add random Gaussian noise
confidence.band(lm(tmpy~tmpx))

install.packages("car")
library(car)
data  <- mtcars
is.matrix(data)
is.data.frame(data)
names(data)
model <- lm(log(mpg) ~ cyl + disp + gear+carb, data=data)
qqPlot(model,labels = row.names(data),id.method = "identify",
       simulate= TRUE, main='QQ PLOT')
qqPlot(model,labels = row.names(data),simulate= TRUE, main='QQ PLOT')
help(qqPlot)
confidenceEllipse(model)
modelb <- lm(log(mpg) ~ cyl, data=data)
qqPlot(modelb,labels = row.names(data),simulate= TRUE, main='QQ PLOT')
confidenceEllipse(modelb)

confidence.band(lm(log(mpg) ~ cyl, data=data))

install.packages("GGally")
library(GGally)
ggpairs(data[,1:3], title="correlogram with ggpairs()") 
ggpairs(data, columns=1:3, ggplot2::aes(colour=as.factor(cyl))
        ggpairs(data, columns=1:3, ggplot2::aes(colour=as.factor(cyl))))        
str(data) #cyl is numeric in the data



